@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: DAV
 version: 1.2
-id: DAV-1.2-3b3a912573602d1fe08885f2a63ee70e
-key: DAV_IfBqLnfD1LP1JqDdx8yWAv
+id: DAV-1.2-647dfea1c7e71a9513787d351de0ad61
+key: DAV_JYp4OJ31XND9RowtrsUj6M
 license: GPL-3
 copyright: Copyright (C) 2012-2015  Clint Adams
 maintainer: clint@debian.org
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/DAV-1.2
-hs-libraries: HSDAV-1.2-IfBqLnfD1LP1JqDdx8yWAv
+hs-libraries: HSDAV-1.2-JYp4OJ31XND9RowtrsUj6M
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -43,8 +43,8 @@ depends:
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
-    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
-    xml-hamlet-0.4.0.11-bb923780c67b6fee1eb342eb208cd081
+    xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
+    xml-hamlet-0.4.0.11-d3cd1497a831c0083fe8a118a6e44493
 haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
 haddock-html: /usr/share/doc/haskell-dav/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
